@@ -2,11 +2,10 @@ from .gui_utils import *
 from .utils import *
 
 from .config import Config
-from .re_variants import Re_Variants
 
 from .linestyler import LineStyler
 from .figman import FigManager
-from .grapher import rcParams
-from .grapher import Grapher
+from .rcparams import rcParams
+from .graphs import Grapher
 
 from .app import App
