@@ -5,7 +5,7 @@ import os
 import re
 import sys
 
-from .grapher import rcParams
+from .rcparams import rcParams
 from .utils import dhms_to_sec, die, is_dir_writable
 
 poi_acc_cpu_default = 10
@@ -20,6 +20,19 @@ class Config:
 
         self._filterfoos = []
 
+        self.cores = 1
+        self.toptype = None
+
+        # Some versions of procps top have values that others don't
+        # So far it's either mem_cached or mem_available
+        self.mem_cached_or_available = "mem_cached"
+        self.mem_unit = "KiB"
+
+        self.has_cpu_column = False
+        self.has_cpu_rows = False
+        self.has_full_task_info = False
+        self.has_swap = False
+
         self.poi_acc_cpu = None
         self.poi_categories = "categories: "  # subtitle of processes graph key
         self.profiling_tag = None
@@ -496,9 +509,9 @@ class Config:
             if self.ignore_case:
                 flags = re.IGNORECASE
 
-            poi_regex = re.compile(self.poi_regex, flags)
+            self.poi_regex = re.compile(self.poi_regex, flags)
             self._filterfoos.append(
-                lambda command, pid, timestamp: poi_regex.match(command) is not None
+                lambda command, pid, timestamp: self.poi_regex.match(command) is not None
             )
             self.poi_categories += (
                 f"/{self.poi_regex}/{'i' if self.ignore_case else ''} "
