@@ -117,7 +117,7 @@ class FigManager:
         self.title, _, self.subtitle = title.partition("\n")
         self.fig = plt.figure() if fig is None else fig
         self.plots = self.fig.subplots(x, y)
-        self.fig.canvas.set_window_title(self.title)
+        self.fig.canvas.manager.set_window_title(self.title)
 
         win = self.fig.canvas.manager.window
         win.geometry(window_size)  # Tkinter specific
