@@ -3,9 +3,9 @@
 
 
 def list_processes(self):
-    for command in sorted(self.processes.keys()):
+    for command in sorted(self._processes.keys()):
         pids = []
-        for pid in sorted(self.processes[command].keys()):
+        for pid in sorted(self._processes[command].keys()):
             if self.config.list_processes >= 2:
                 print(
                     f"{command} [{pid}]"
